/*-----------------------------------------------
   ATtiny824 TCB0 50ms periodic interrupt

     VDD 1|???????|14 GND 
     PA4 2|       |13 PA3 ---- LED
     PA5 3|       |12 PA2
     PA6 4|       |11 PA1 
     PA7 5|       |10 UPDI
     PB3 6|       | 9 PB0 
     PB2 7|_______| 8 PB1 

  2MHz/2/50000 = 20Hz    T = 50ms
---------------------------------------------*/

#include <avr/io.h>
#include <avr/interrupt.h>

ISR(TCB0_INT_vect)
{
  PORTA.OUTTGL = PIN3_bm;         // toggle PA3
  TCB0.INTFLAGS = TCB_CAPT_bm;    // clear TCB0 interrupt flag
} 

int main(void)
{
  _PROTECTED_WRITE(CLKCTRL.MCLKCTRLB, CLKCTRL_PDIV_10X_gc | CLKCTRL_PEN_bm);    // Main Clock 2MHz

  PORTA.DIRSET = PIN3_bm;                              // PA3 as output

  TCB0.CCMP = 0xC350;                                  // Timeout value (50000)
  TCB0.CTRLA = TCB_CLKSEL_DIV2_gc | TCB_ENABLE_bm;     // TCB0 Clock 1MHz, enable TCB0
  TCB0.INTCTRL = TCB_CAPT_bm;                          // Enable Capture or Timeout interrupt

  sei();                                               // Enable Global Interrupts

  while(1) 
  {
   ;
  }
}
